# Electromagnetic response section (ERS) detection algorithm

This algorithm was designed to detect the time range of the electromagnetic response cause by pulse excitation in signal series gained by ultrasonic measurements 
(combined compression- and shear wave measurements, FreshCon device).
This analysis is also the basis for the conference mansucript and poster presented at **Journées de Cofrend 2023, Marseille (FR)**.

Why is this useful?
- provide subsequential analysis with additional information about the signal data
- detect time range of the electromagnetic response section (ERS) cause by pulse excitation


## Program directories and files

- **analysis** ... directory, algorithm and tools
- **analysis/export** ... directory, export directory (*.tex)
- **analysis/results** ... directory, analysis results directory (*.oct)
- **fileio** ... directory, file input and output functions
- **results** ... directory, computation results, output files
- **structure** ... directory, data structure handling functions
- **textools** ... directory, TeX export files (*.tex), used in LaTeX code of manuscript
- anaers_param.m ... function file, analysis parameters
- anaers_run_analysis.m ... function file, run analysis, electromagnetic response section (ERS) detection
- anaers_run_export.m ... function file, export analysis results
- anaers_run_plot.m ... function file, export selected signal data from datasets
- anaers_run_tsstats.m ... function file, run statistics for all datasets
- init.m ... function file, initialize program


## Software requirements

In order to run the function files you need to install GNU octave. GNU octave is available in almost all Linux 
distributions but also for Microsoft Windows. The code was written and tested using GNU octave 6.2.0.


## Usage

To reproduce the results used in the conference paper and poster, you need to perform the following steps (in given order).
The computation results are written to GNU octave binary files as well as to TeX code files into the **results** and **export** subdirectories in the **analysis** directory.
- Step 1: download datasets from repository of Graz University of Technology, DOI: 10.3217/psrys-yep17
- Step 2: extract the archive to a directory of your choice
- Step 3: open GNU octave and change the working directory to the directory containing the program code
- Step 4: adjust path to dataset and source code directory paths by changing the variables **r_ds.dspath** and **r_ds.scpath** in **anaers_param.m**
- Step 5: initialize program: **> init**
- Step 6: run ERS detection analysis: **> anaers_run_analysis**
- Step 7: run analysis result export: **> anaers_run_export**
- Step 8: run test series statistics: **> anaers_run_tsstats**
- Step 9: run plot data export: **> anaers_run_plot**


## Help

Each function file contains a brief description of the function parameters, the values returned and the usage.
To read the help, open the function file in a text edit or type "help <function_file_name>" in the GNU octave command line.


## License

Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
License: MIT
This file is part of the PhD thesis of Jakob Harden.

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

