## Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
## License: MIT
## This file is part of the PhD thesis of Jakob Harden.
## 
## Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
## documentation files (the “Software”), to deal in the Software without restriction, including without 
## limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
## the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
## 
## THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
## THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
## AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
## TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
##
## Return global computation parameters, settings
##
## Usage: [r_ds] = anaers_param()
##
## r_ds ... return: parameter data structure, <struct>
##
## see also: 
##
function [r_ds] = anaers_param()
  
  ## init parameter dada structure
  r_ds.obj = 'anaers_struct_param';
  r_ds.ver = uint16([1, 0]);
  
  ## computer name
  ##r_ds.pcname = gethostname();
  
  ## set paths
  r_ds.dspath = '/mnt/data/0_test_series';
  r_ds.scpath = '/mnt/data/1_development/code_cofrend23/analysis';
  
  #############################################################################
  ## signal preconditioning
  
  ## bias removal mode
  r_ds.mod.rmbias = true;
  
  ## outlyer dection mode
  r_ds.mod.outlyers = true;
  
  ## noise removal mode
  r_ds.mod.rmnoise = true;
  
  ## estimated size of analysis range, number of samples
  r_ds.narfb = 150; # fallback value
  r_ds.nar25 = 100; # d = 25mm
  r_ds.nar50 = 130; # d = 50mm
  r_ds.nar70 = 150; # d = 70mm
  
  ## outlyer detection threshold (quantile limit)
  r_ds.thol = 0.95; # upper limit, 95%
  
  #############################################################################
  ## wavelet analysis parameters
  ## function type
  r_ds.wla.ftp = 'tp2';
  
  ## start shift index
  ## distance to trigger point
  r_ds.wla.si0 = 10;
  
  ## end shift index
  ## distance to trigger point
  r_ds.wla.si1 = 30;
  
  ## shift step size
  r_ds.wla.sss = 1;
  
  ## wavelet start length
  ## will be updated by algorithm in function file anaers_algo.m
  r_ds.wla.ln0 = 40;
  
  ## wavelet end length
  ## will be updated by algorithm in function file anaers_algo.m
  r_ds.wla.ln1 = 50;
  
  ## wavelet length step size
  r_ds.wla.lss = 1;
  
  ## fixed wavelet parameters (from visual inspection)
  ## for detailed description see function file anaers_wavelet.m
  r_ds.wla.par_b = 10;
  r_ds.wla.par_d = r_ds.wla.par_b * 2;
  r_ds.wla.par_e = 0.3;
  r_ds.wla.par_f = 1.0;
  r_ds.wla.par_g = 0.7;
  
  #############################################################################
  ## statistics
  ## estimate for disturbance range 1, number of samples (DR = wl = b + 2 * c + d)
  ## use electric network properties, see also anaers_est_discharge.m
  r_ds.stats.ewl1 = r_ds.wla.par_b + 2 * 21 + r_ds.wla.par_d;
  
  ## estimate for disturbance range 2, number of samples (DR = wl = b + 2 * c + d)
  ## use pulse width, pw = 2.5 usec = 25 samples (at a sampling rate of 10 MHz)
  r_ds.stats.ewl2 = r_ds.wla.par_b + 2 * 25 + r_ds.wla.par_d;
  
  #############################################################################
  ## post processing
  
  ## save binaray file, analysis results
  r_ds.post.save_bin = true;
  
  ## save TeX output, analysis results
  r_ds.post.save_tex = true;
  
endfunction
