## Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
## License: MIT
## This file is part of the PhD thesis of Jakob Harden.
## 
## Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
## documentation files (the “Software”), to deal in the Software without restriction, including without 
## limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
## the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
## 
## THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
## THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
## AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
## TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
##
## Return dataset definitions used for the analysis, cem1 pastes
##
## Usage: [r_ds] = anaers_dsdefs_cem1()
##
## r_ds ... return: dataset definition data structure, <struct>
##   .dsl ... dataset list, [<struct>]
##   .def ... subset definitions, <struct>
##
## see also: 
##
function [r_ds] = anaers_dsdefs_cem1()
  
  ## dataset directory path
  r_ds.dsdir = 'ts1_cem1_paste/oct';
  
  ## analysis result path
  r_ds.ardir = 'results/cem1';
  
  ## statistics result path
  r_ds.stdir = 'stats/cem1';
  
  ## data export path (TeX files)
  r_ds.exdir = 'export/cem1';
  
  ## dataset list
  s1 = 'ts1';
  s2 = {'wc040', 'wc045', 'wc050', 'wc055', 'wc060'};
  s3 = {'d25', 'd50', 'd70'};
  s4 = {'1', '2', '3', '4', '5', '6'};
  s5 = 'oct';
  n2 = size(s2, 2);
  n3 = size(s3, 2);
  n4 = size(s4, 2);
  cnt = 1;
  for i = 1 : n2
    s_wc = s2{i};
    for ii = 1 : n3
      s_di = s3{ii};
      for iii = 1 : n4
        s_tn = s4{iii};
        r_ds.dsl(cnt).wc = s_wc;
        r_ds.dsl(cnt).di = s_di;
        r_ds.dsl(cnt).tn = s_tn;
        r_ds.dsl(cnt).fn = sprintf('%s_%s_%s_%s.%s', s1, s_wc, s_di, s_tn, s5);
        cnt = cnt + 1;
      endfor
    endfor
  endfor
  
  ## all tests
  idx_all = 1 : 90;
  r_ds.def.all = hlp_def(1 : 90, 'ts1_all');
  
  ## by wc-ratio: all, part 1, part 2
  sub_p1 = [1:3, 7:9, 13:15];
  sub_p2 = sub_p1 + 3;
  idx_wc040 = 1 : 18;
  r_ds.def.wc040.all = hlp_def(idx_wc040, 'ts1_wc040_all');
  r_ds.def.wc040.p1 = hlp_def(idx_wc040(sub_p1), 'ts1_wc040_p1');
  r_ds.def.wc040.p2 = hlp_def(idx_wc040(sub_p2), 'ts1_wc040_p2');
  idx_wc045 = idx_wc040 + 18;
  r_ds.def.wc045.all = hlp_def(idx_wc045, 'ts1_wc045_all');
  r_ds.def.wc045.p1 = hlp_def(idx_wc045(sub_p1), 'ts1_wc045_p1');
  r_ds.def.wc045.p2 = hlp_def(idx_wc045(sub_p2), 'ts1_wc045_p2');
  idx_wc050 = idx_wc045 + 18;
  r_ds.def.wc050.all = hlp_def(idx_wc050, 'ts1_wc050_all');
  r_ds.def.wc050.p1 = hlp_def(idx_wc050(sub_p1), 'ts1_wc050_p1');
  r_ds.def.wc050.p2 = hlp_def(idx_wc050(sub_p2), 'ts1_wc050_p2');
  idx_wc055 = idx_wc050 + 18;
  r_ds.def.wc055.all = hlp_def(idx_wc055, 'ts1_wc055_all');
  r_ds.def.wc055.p1 = hlp_def(idx_wc055(sub_p1), 'ts1_wc055_p1');
  r_ds.def.wc055.p2 = hlp_def(idx_wc055(sub_p2), 'ts1_wc055_p2');
  idx_wc060 = idx_wc055 + 18;
  r_ds.def.wc060.all = hlp_def(idx_wc060, 'ts1_wc060_all');
  r_ds.def.wc060.p1 = hlp_def(idx_wc060(sub_p1), 'ts1_wc060_p1');
  r_ds.def.wc060.p2 = hlp_def(idx_wc060(sub_p2), 'ts1_wc060_p2');
  
  ## by distance: all, part 1, part 2
  sub_p1 = [1:3, 7:9, 13:15, 19:21, 25:27];
  sub_p2 = sub_p1 + 3;
  idx_d25 = [1:6, 19:24, 37:42, 55:60, 73:78];
  r_ds.def.d25.all = hlp_def(idx_d25, 'ts1_d25_all');
  r_ds.def.d25.p1 = hlp_def(idx_d25(sub_p1), 'ts1_d25_p1');
  r_ds.def.d25.p2 = hlp_def(idx_d25(sub_p2), 'ts1_d25_p2');
  idx_d50 = idx_d25 + 6;
  r_ds.def.d50.all = hlp_def(idx_d50, 'ts1_d50_all');
  r_ds.def.d50.p1 = hlp_def(idx_d50(sub_p1), 'ts1_d50_p1');
  r_ds.def.d50.p2 = hlp_def(idx_d50(sub_p2), 'ts1_d50_p2');
  idx_d70 = idx_d50 + 6;
  r_ds.def.d70.all = hlp_def(idx_d70, 'ts1_d70_all');
  r_ds.def.d70.p1 = hlp_def(idx_d70(sub_p1), 'ts1_d70_p1');
  r_ds.def.d70.p2 = hlp_def(idx_d70(sub_p2), 'ts1_d70_p2');
  
  ## by wc-ratio and distance
  ## wc040: all, part 1, part 2
  sub_p1 = 1 : 3;
  sub_p2 = sub_p1 + 3;
  idx_wc040_d25 = 1 : 6;
  r_ds.def.wc040.d25.all = hlp_def(idx_wc040_d25, 'ts1_wc040_d25_all');
  r_ds.def.wc040.d25.p1 = hlp_def(idx_wc040_d25(sub_p1), 'ts1_wc040_d25_p1');
  r_ds.def.wc040.d25.p2 = hlp_def(idx_wc040_d25(sub_p2), 'ts1_wc040_d25_p2');
  idx_wc040_d50 = idx_wc040_d25 + 6;
  r_ds.def.wc040.d50.all = hlp_def(idx_wc040_d50, 'ts1_wc040_d50_all');
  r_ds.def.wc040.d50.p1 = hlp_def(idx_wc040_d50(sub_p1), 'ts1_wc040_d50_p1');
  r_ds.def.wc040.d50.p2 = hlp_def(idx_wc040_d50(sub_p2), 'ts1_wc040_d50_p2');
  idx_wc040_d70 = idx_wc040_d50 + 6;
  r_ds.def.wc040.d70.all = hlp_def(idx_wc040_d70, 'ts1_wc040_d70_all');
  r_ds.def.wc040.d70.p1 = hlp_def(idx_wc040_d70(sub_p1), 'ts1_wc040_d70_p1');
  r_ds.def.wc040.d70.p2 = hlp_def(idx_wc040_d70(sub_p2), 'ts1_wc040_d70_p2');
  ## wc045: all, part 1, part 2
  idx_wc045_d25 = 19 : 24;
  r_ds.def.wc045.d25.all = hlp_def(idx_wc045_d25, 'ts1_wc045_d25_all');
  r_ds.def.wc045.d25.p1 = hlp_def(idx_wc045_d25(sub_p1), 'ts1_wc045_d25_p1');
  r_ds.def.wc045.d25.p2 = hlp_def(idx_wc045_d25(sub_p2), 'ts1_wc045_d25_p2');
  idx_wc045_d50 = idx_wc045_d25 + 6;
  r_ds.def.wc045.d50.all = hlp_def(idx_wc045_d50, 'ts1_wc045_d50_all');
  r_ds.def.wc045.d50.p1 = hlp_def(idx_wc045_d50(sub_p1), 'ts1_wc045_d50_p1');
  r_ds.def.wc045.d50.p2 = hlp_def(idx_wc045_d50(sub_p2), 'ts1_wc045_d50_p2');
  idx_wc045_d70 = idx_wc045_d50 + 6;
  r_ds.def.wc045.d70.all = hlp_def(idx_wc045_d70, 'ts1_wc045_d70_all');
  r_ds.def.wc045.d70.p1 = hlp_def(idx_wc045_d70(sub_p1), 'ts1_wc045_d70_p1');
  r_ds.def.wc045.d70.p2 = hlp_def(idx_wc045_d70(sub_p2), 'ts1_wc045_d70_p2');
  ## wc050: all, part 1, part 2
  idx_wc050_d25 = 37 : 42;
  r_ds.def.wc050.d25.all = hlp_def(idx_wc050_d25, 'ts1_wc050_d25_all');
  r_ds.def.wc050.d25.p1 = hlp_def(idx_wc050_d25(sub_p1), 'ts1_wc050_d25_p1');
  r_ds.def.wc050.d25.p2 = hlp_def(idx_wc050_d25(sub_p2), 'ts1_wc050_d25_p2');
  idx_wc050_d50 = idx_wc050_d25 + 6;
  r_ds.def.wc050.d50.all = hlp_def(idx_wc050_d50, 'ts1_wc050_d50_all');
  r_ds.def.wc050.d50.p1 = hlp_def(idx_wc050_d50(sub_p1), 'ts1_wc050_d50_p1');
  r_ds.def.wc050.d50.p2 = hlp_def(idx_wc050_d50(sub_p2), 'ts1_wc050_d50_p2');
  idx_wc050_d70 = idx_wc050_d50 + 6;
  r_ds.def.wc050.d70.all = hlp_def(idx_wc050_d70, 'ts1_wc050_d70_all');
  r_ds.def.wc050.d70.p1 = hlp_def(idx_wc050_d70(sub_p1), 'ts1_wc050_d70_p1');
  r_ds.def.wc050.d70.p2 = hlp_def(idx_wc050_d70(sub_p2), 'ts1_wc050_d70_p2');
  ## wc055: all, part 1, part 2
  idx_wc055_d25 = 55 : 60;
  r_ds.def.wc055.d25.all = hlp_def(idx_wc055_d25, 'ts1_wc055_d25_all');
  r_ds.def.wc055.d25.p1 = hlp_def(idx_wc055_d25(sub_p1), 'ts1_wc055_d25_p1');
  r_ds.def.wc055.d25.p2 = hlp_def(idx_wc055_d25(sub_p2), 'ts1_wc055_d25_p2');
  idx_wc055_d50 = idx_wc055_d25 + 6;
  r_ds.def.wc055.d50.all = hlp_def(idx_wc055_d50, 'ts1_wc055_d50_all');
  r_ds.def.wc055.d50.p1 = hlp_def(idx_wc055_d50(sub_p1), 'ts1_wc055_d50_p1');
  r_ds.def.wc055.d50.p2 = hlp_def(idx_wc055_d50(sub_p2), 'ts1_wc055_d50_p2');
  idx_wc055_d70 = idx_wc055_d50 + 6;
  r_ds.def.wc055.d70.all = hlp_def(idx_wc055_d70, 'ts1_wc055_d70_all');
  r_ds.def.wc055.d70.p1 = hlp_def(idx_wc055_d70(sub_p1), 'ts1_wc055_d70_p1');
  r_ds.def.wc055.d70.p2 = hlp_def(idx_wc055_d70(sub_p2), 'ts1_wc055_d70_p2');
  ## wc060: all, part 1, part 2
  idx_wc060_d25 = 73 : 78;
  r_ds.def.wc060.d25.all = hlp_def(idx_wc060_d25, 'ts1_wc060_d25_all');
  r_ds.def.wc060.d25.p1 = hlp_def(idx_wc060_d25(sub_p1), 'ts1_wc060_d25_p1');
  r_ds.def.wc060.d25.p2 = hlp_def(idx_wc060_d25(sub_p2), 'ts1_wc060_d25_p2');
  idx_wc060_d50 = idx_wc060_d25 + 6;
  r_ds.def.wc060.d50.all = hlp_def(idx_wc060_d50, 'ts1_wc060_d50_all');
  r_ds.def.wc060.d50.p1 = hlp_def(idx_wc060_d50(sub_p1), 'ts1_wc060_d50_p1');
  r_ds.def.wc060.d50.p2 = hlp_def(idx_wc060_d50(sub_p2), 'ts1_wc060_d50_p2');
  idx_wc060_d70 = idx_wc060_d50 + 6;
  r_ds.def.wc060.d70.all = hlp_def(idx_wc060_d70, 'ts1_wc060_d70_all');
  r_ds.def.wc060.d70.p1 = hlp_def(idx_wc060_d70(sub_p1), 'ts1_wc060_d70_p1');
  r_ds.def.wc060.d70.p2 = hlp_def(idx_wc060_d70(sub_p2), 'ts1_wc060_d70_p2');
  
endfunction

############################################################################################################################################
## Helper function: create list definition data structure
## p_idx  ... index list, [<uint>]
## p_code ... index list code/name, <str>
## r_ds   ... return: list definition data structure, <struct>
function [r_ds] = hlp_def(p_idx, p_code)
  
  r_ds.idx = p_idx;
  r_ds.code = p_code;
  
endfunction
