## Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
## License: MIT
## This file is part of the PhD thesis of Jakob Harden.
## 
## Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
## documentation files (the “Software”), to deal in the Software without restriction, including without 
## limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
## the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
## 
## THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
## THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
## AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
## TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
##
## TeXify atomic attribute element
##
## Usage: [r_str] = struct_objattrib_totex(p_ds, p_mo)
##
## p_ds ... data structure "objattrib", <AAE/struct>
## p_dn ... data structure name (used as variable name prefix), <str>
## r_tc ... return: TeX code representation of structure element(s), {<str>}
##
## see also: struct_objattrib
##
function [r_tc] = struct_objattrib_totex(p_ds, p_dn)
  
  ## check arguments
  if (nargin < 2)
    help struct_objattrib_totex;
    error('Less arguments given!');
  endif
  
  ## check type of data structure
  if (not(isfield(p_ds, 'obj')))
    warning('Data structure is not of type ATTRIBUTE! name = %s', p_dn);
    r_tc = '';
    return;
  else
    if (not(p_ds.obj == 'AAE'))
      warning('Data structure is not of type ATTRIBUTE! name = %s', p_dn);
      r_tc = '';
      return;
    endif
  endif
  
  ## render data structure to TeX code
  r_tc = {};
  ##r_tc = [r_tc; sprintf('\\def\\%sobj{%s}', p_dn, p_ds.obj)];
  ##r_tc = [r_tc; sprintf('\\def\\%sver{%d.%d}', p_dn, p_ds.ver(1), p_ds.ver(2))];
  ##r_tc = [r_tc; sprintf('\\def\\%st{%s}', p_dn, p_ds.t)];
  ##r_tc = [r_tc; sprintf('\\def\\%sd{%s}', p_dn, p_ds.d)];
  if (iscellstr(p_ds.v))
    for i = 1 : max(size(p_ds.v))
      r_tc = [r_tc; sprintf('\\def\\%sv%d{%s}', p_dn, i, p_ds.v{i})];
    endfor
  else
    r_tc = [r_tc; sprintf('\\def\\%sv{%s}', p_dn, p_ds.v)];
  endif
  
endfunction
