## Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
## License: MIT
## This file is part of the PhD thesis of Jakob Harden.
## 
## Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
## documentation files (the “Software”), to deal in the Software without restriction, including without 
## limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
## the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
## 
## THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
## THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
## AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
## TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
##
## Return data structure containing the TeX output settings
##
## Usage: [r_ds] = tex_settings(p_mo)
##
## p_mod ... mode, optional, <str>
##             'force': force update
## r_ds  ... return: TeX output settings, <struct>
##
## see also: 
##
function [r_ds] = tex_settings(p_mo)
  
  global wavupv_tex_settings;
  
  ## check arguments
  if (nargin < 1)
    p_mo = 'normal';
  endif
  
  ## use existing global variable instead of creating a new settings data structure (faster)
##  if (strcmpi(p_mo, 'normal'))
##    if (exist('wavupv_tex_settings', 'var') == 1)
##      r_ds = wavupv_tex_settings;
##      return;
##    endif
##  endif
  
  ## define command prefix
  r_ds.def_pfx = '\\expandafter\\def\\csname';
  
  ## define command suffix
  r_ds.def_sfx = '\\endcsname';
  
  ## begin filecontents environment
  r_ds.begin_fc = '\begin{filecontents}';
  
  ## end filecontents environment
  r_ds.end_fc = '\end{filecontents}';
  
  ## variable name prefix
  ## this is to avoid conflicts with other variables defined in LaTeX document
  ## always add a dot at the end of the variable name
  r_ds.var_pfx = 'oct2tex.';
  
endfunction
