## Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
## License: MIT
## This file is part of the PhD thesis of Jakob Harden.
## 
## Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
## documentation files (the “Software”), to deal in the Software without restriction, including without 
## limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
## the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
## 
## THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
## THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
## AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
## TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
##
## TeXify atomic reference element
##
## Usage: [r_tc] = tex_struct_objref(p_ds, p_sp, p_px)
##
## p_ds ... atomic data structure "objref", <AAE/struct>
## p_sp ... structure path prefix, <str>
## p_px ... structure path prefix, optional, <str>
## r_tc ... return: TeX code representation of structure element(s), {<str>}
##
## see also: struct_objref
##
function [r_tc] = tex_struct_objref(p_ds, p_sp, p_px)
  
  ## check arguments
  if (nargin < 2)
    help tex_struct_objref;
    error('Less arguments given!');
  endif
  if (nargin < 3)
    spath = p_sp;
  else
    spath = [p_px, p_sp];
  endif
  
  ## check type of data structure
  if (not(isfield(p_ds, 'obj')))
    warning('Data structure is not of type REFERENCE! name = %s', p_sp);
    r_tc = '';
    return;
  else
    if (not(p_ds.obj == 'ARE'))
      warning('Data structure is not of type REFERENCE! name = %s', p_sp);
      r_tc = '';
      return;
    endif
  endif
  
  ## render data structure to TeX code
  r_tc = {};
  r_tc = tex_def_scalar([spath, '.obj'], '%s', p_ds.obj, r_tc);
  r_tc = tex_def_csvarray([spath, '.ver'], '%d', p_ds.ver, r_tc);
  r_tc = tex_def_scalar([spath, '.t'], '%s', p_ds.t, r_tc);
  r_tc = tex_def_scalar([spath, '.d'], '%s', p_ds.d, r_tc);
  r_tc = tex_def_csvarray([spath, '.i'], '%d', p_ds.i, r_tc);
  r_tc = tex_def_dotarray([spath, '.r'], '%s', p_ds.r, r_tc);
  
endfunction
